California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 005 - ACA 1 (RES. CH. 173, 2023); ACA 10 (RES. CH. 134, 2024) AGUIAR-CURRY. LOCAL GOVERNMENT FINANCING: AFFORDABLE HOUSING AND PUBLIC INFRASTRUCTURE: VOTER APPROVAL. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1442599 | NO ON PROPOSITION 5 - PROTECT LOCAL TAXPAYERS, SPONSORED BY CALIFORNIA HOMEOWNERS, BUSINESSES, AND TAXPAYERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1400190 | HOMEOWNERSHIP FOR FAMILIES SPONSORED BY CALIFORNIA ASSOCIATION OF REALTORS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1471736 | NPH ACTION FUND (NONPROFIT 501(C) (4)), YES ON PROP. 5 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1405857 | CHAN ZUCKERBERG INITIATIVE ADVOCACY - YES ON 5 (NONPROFIT 501(C)(4)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
931447 | PROTECT PROP. 13, A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION, NO ON PROP. 5 | OPPOSE